CameraController class

Inheritance

Constructors

CameraController(CameraDescription? description, ResolutionPreset? resolutionPreset, {bool? enableAudio = true, ResolutionPreset? streamingPreset, bool? androidUseOpenGL = false})

Properties

androidUseOpenGL → bool?
final
description → CameraDescription?
final
enableAudio → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
resolutionPreset → ResolutionPreset?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamingPreset → ResolutionPreset?
final
value ↔ CameraValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → Future<void>
Releases the resources of this camera.
override
getStreamStatistics() → Future<StreamStatistics>
Get statistics about the rtmp stream.
initialize() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pauseVideoStreaming() → Future<void>
Pause video recording.
prepareForVideoRecording() → Future<void>
prepareForVideoStreaming() → Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resumeVideoStreaming() → Future<void>
Resume video streaming after pausing.
startImageStream(onLatestImageAvailable onAvailable) → Future<void>
startVideoStreaming(String url, {int bitrate = 1200 * 1024, required bool androidUseOpenGL}) → Future<void>
Start a video streaming to the url in url`.
stopEverything() → Future<void>
Stop streaming.
stopImageStream() → Future<void>
Stop streaming images from platform camera.
stopVideoStreaming() → Future<void>
Stop streaming.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited