CameraDescription class

Constructors

CameraDescription({required String name, required CameraLensDirection lensDirection, required int sensorOrientation})

Properties

hashCode → int
The hash code for this object.
no setteroverride
lensDirection → CameraLensDirection
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensorOrientation → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override