CameraValue class

Constructors

CameraValue({required bool isInitialized, String? errorDescription, Size? previewSize, int? previewQuarterTurns, required bool isRecordingVideo, required bool? isTakingPicture, required bool? isStreamingImages, required bool isStreamingVideoRtmp, required bool isRecordingPaused, required bool isStreamingPaused})
CameraValue.uninitialized()

Properties

aspectRatio → double
no setter
errorDescription → String?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
final
isRecordingPaused → bool
no setter
isRecordingVideo → bool
final
isStreamingImages → bool?
final
isStreamingPaused → bool
no setter
isStreamingVideoRtmp → bool
final
isTakingPicture → bool?
final
previewQuarterTurns → int?
final
previewSize → Size?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isInitialized, bool? isRecordingVideo, bool? isStreamingVideoRtmp, bool? isTakingPicture, bool? isStreamingImages, String? errorDescription, Size? previewSize, int? previewQuarterTurns, bool? isRecordingPaused, bool? isStreamingPaused}) → CameraValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited