Plane class

A single color plane of image data.

The number and meaning of the planes in an image are determined by the format of the Image.

Properties

bytes → Uint8List
final
bytesPerPixel → int?
final
bytesPerRow → int
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited