StreamStatistics class

Constructors

StreamStatistics({required int cacheSize, required int sentAudioFrames, required int sentVideoFrames, required int droppedAudioFrames, required int droppedVideoFrames, required int bitrate, required int width, required int height, required bool isAudioMuted})

Properties

bitrate → int
final
cacheSize → int
final
droppedAudioFrames → int
final
droppedVideoFrames → int
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
isAudioMuted → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentAudioFrames → int
final
sentVideoFrames → int
final
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited