CameraChannel class

Constructors

CameraChannel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

callbacks → Map<int, dynamic>
final
channel → MethodChannel
final
nextHandle ↔ int
getter/setter pair

Static Methods

registerCallback(int handle, CameraCallback callback) → void
unregisterCallback(int handle) → void