CameraConfigurator class abstract

Abstract class used to create a common interface across platform APIs.

Constructors

CameraConfigurator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
previewTextureId → int
Texture id that can be used to send camera frames to a Texture widget.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPreviewTexture() → Future<int>
Retrieves a valid texture Id to be used with a Texture widget.
dispose() → Future<void>
Dispose all resources and disables further use of this configurator.
initialize() → Future<void>
Initializes the camera on the device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<void>
Begins the flow of data between the inputs and outputs connected to the camera instance.
stop() → Future<void>
Stops the flow of data between the inputs and outputs connected to the camera instance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited