CameraDescriptionNew class abstract

Abstract class used to create a common interface to describe a camera from different platform APIs.

This provides information such as the name of the camera and direction the lens face.

Implementers

Constructors

CameraDescriptionNew()

Properties

direction → LensDirection
Location of the camera on the device.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
Identifier for this camera.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited