NativeTexture class

Mixed-in types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textureId → int
final

Methods

asMap() → Map<String, dynamic>
Creates a description of the object compatible with PlatformChannels.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

allocate() → Future<NativeTexture>