Camera class

Mixed-in types

Properties

handle → int
Identifier for an object on the native side of the plugin.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
previewTexture ← NativeTexture
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → Future<void>
startPreview() → Future<void>
stopPreview() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getCameraInfo(int cameraId) → Future<CameraInfo>
getNumberOfCameras() → Future<int?>
open(int cameraId) → Camera